@@ -24,6 +24,6 @@
 #include <stdbool.h>
 
 bool
-filter_set ( int sock, const struct config_op *co );
+filter_set ( int sock, const int flags_proto );
 
 #endif  // FILTER_H
