@@ -25,10 +25,10 @@
 #include "rate.h"
 
 int
-log_init ( const struct config_op * );
+log_init ( const char *path_log );
 
 int
-log_file ( process_t **processes, const size_t tot_process );
+log_file ( process_t **processes );
 
 void
 log_free ( void );
