@@ -23,9 +23,8 @@
 
 #include "config.h"
 
-// inicializa o socket para escutar conexões
 int
-socket_init ( const struct config_op *co );
+socket_init ( const char *iface );
 
 void
 socket_free ( int sock );
