@@ -1,4 +1,23 @@
 
+/*
+ *  Copyright (C) 2021 Mayco S. Berghetti
+ *
+ *  This file is part of Netproc.
+ *
+ *  Netproc is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #ifndef VECTOR_H
 #define VECTOR_H
 
@@ -9,17 +28,17 @@
  @param nmeb, number of member initial in vector, if 0 default is 16
  @param size, size of one member in array
 
- @return memory to user or null
+ @return memory to user or null on error
 */
 void *
-vector_new ( size_t nmeb, size_t size_member );
+vector_new ( size_t size_member );
 
 /*
  copy user data into vector
  @oaram mem, pointer returned from vector_new
  @param data, pointer to user data to push in vector
 
- @return 1 if success or 0 in error
+ @return 1 if success or 0 on error
 */
 int
 vector_push_ ( void **mem, void *data );
@@ -30,13 +49,13 @@ vector_push_ ( void **mem, void *data );
   remove last element from vector
   @oaram mem, pointer returned from vector_new
 
-  @return number of elements in vector
+  @return element removed from vector
 */
-int
+void *
 vector_pop ( void *mem );
 
 /*
-  remove all elements in vector
+  remove all vector elements
   @oaram mem, pointer returned from vector_new
 */
 void
@@ -50,7 +69,7 @@ size_t
 vector_size ( void *mem );
 
 /*
-  free dinamyc memory allocated to vector
+  free vector
   @oaram mem, pointer returned from vector_new
 */
 void
